@@ -1,9 +1,10 @@
 from .common import (
-    Entity, Domain, DataDict, RecordList)
+    Entity, DataDict, RecordList)
+from .filterer import Domain
 from .repository import (
     Repository, MemoryRepository,
     JsonRepository, SqlRepository, RestRepository)
 
 __author__ = 'Knowark'
 __email__ = 'info@knowark.com'
-__version__ = '0.3.4'
+__version__ = '0.4.0'
