@@ -3,7 +3,7 @@ from typing import TypeVar
 
 class Entity:
     def __init__(self, **attributes) -> None:
-        self.id = attributes.get('id', '')
+        self.id = attributes['id']
         self.created_at = attributes.get('created_at', 0)
         self.updated_at = attributes.get('updated_at', self.created_at)
         self.created_by = attributes.get('created_by', '')
